@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+# Part of Carburetor project
 # Released under GPLv3+ License
 # Danial Behzadi<dani.behzi@ubuntu.com>, 2020-2023.
 
@@ -304,10 +304,3 @@ def on_pluginchooser_response(chooser, task):
     else:
         config.dconf.set_string("plugable-transport", file.get_path())
         actions.setup_pluginbutton()
-
-
-def on_about_realize(window):
-    """
-    insert translators
-    """
-    window.set_translator_credits(config._("translator-credits"))
