@@ -1,19 +1,17 @@
-#!/usr/bin/python3
+# Part of Carburetor project
 # Released under GPLv3+ License
-# Danial Behzadi<dani.behzi@ubuntu.com>, 2020-2022.
+# Danial Behzadi<dani.behzi@ubuntu.com>, 2020-2023.
 
 """
 handle ui related stuff
 """
 
-import gi
-
-gi.require_versions({"Gtk": "4.0"})
-from gi.repository import Gdk, Gtk
+from gi.repository import Gdk, Gio, Gtk
 
 from . import config
 from . import handler
 
+
 builder = Gtk.Builder(scope_object_or_map=handler)
 ui_dir = config.s_data_dir + "/ui"
 
@@ -22,9 +20,12 @@ def initialize_builder() -> None:
     """
     connect builder to files and handlers
     """
-    builder.add_from_file(ui_dir + "/about.ui")
-    builder.add_from_file(ui_dir + "/preferences.ui")
-    builder.add_from_file(ui_dir + "/main.ui")
+    resource = Gio.resource_load(config.s_data_dir + "/res.gresource")
+    Gio.resources_register(resource)
+    prefix = "/io/frama/tractor/carburetor/gtk/"
+    builder.add_from_resource(prefix + "main.ui")
+    builder.add_from_resource(prefix + "preferences.ui")
+    builder.add_from_resource(prefix + "help-overlay.ui")
 
 
 def get(obj: str):
@@ -39,7 +40,8 @@ def css() -> None:
     apply css to ui
     """
     css_provider = Gtk.CssProvider()
-    css_provider.load_from_path(ui_dir + "/style.css")
+    prefix = "/io/frama/tractor/carburetor/gtk/"
+    css_provider.load_from_resource(prefix + "style.css")
     display = Gdk.Display.get_default()
     Gtk.StyleContext.add_provider_for_display(
         display, css_provider, Gtk.STYLE_PROVIDER_PRIORITY_USER
